pub struct TurboTaskLocalContextError {
pub name: RcStr,
pub source: Option<TurboTasksExecutionError>,
}Expand description
Error context for a local task that failed. Unlike TurboTaskContextError,
this stores the task name directly since local tasks don’t have a TaskId.
Fields
name: RcStrsource: Option<TurboTasksExecutionError>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for TurboTaskLocalContextError
impl<'__de, __Context> BorrowDecode<'__de, __Context> for TurboTaskLocalContextError
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for TurboTaskLocalContextError
impl Clone for TurboTaskLocalContextError
Sourcefn clone(&self) -> TurboTaskLocalContextError
fn clone(&self) -> TurboTaskLocalContextError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TurboTaskLocalContextError
impl Debug for TurboTaskLocalContextError
Sourceimpl<__Context> Decode<__Context> for TurboTaskLocalContextError
impl<__Context> Decode<__Context> for TurboTaskLocalContextError
Sourceimpl Encode for TurboTaskLocalContextError
impl Encode for TurboTaskLocalContextError
impl Eq for TurboTaskLocalContextError
impl StructuralPartialEq for TurboTaskLocalContextError