ValueDebugFormat

Trait ValueDebugFormat 

pub trait ValueDebugFormat {
    // Required method
    fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>;
}
Use autoref specialization to implement ValueDebug for T: Debug.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ValueDebugFormat for RcStr

Source

impl ValueDebugFormat for String

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat, K: ValueDebugFormat, L: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat, K: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat> ValueDebugFormat for (A, B, C, D)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat> ValueDebugFormat for (A, B, C)

Source

impl<A: ValueDebugFormat, B: ValueDebugFormat> ValueDebugFormat for (A, B)

Source

impl<A: ValueDebugFormat> ValueDebugFormat for (A,)

Source

impl<K, V, S> ValueDebugFormat for HashMap<K, V, S>
where K: Debug, V: ValueDebugFormat,

Source

impl<K, V> ValueDebugFormat for AutoMap<K, V>
where K: Debug, V: ValueDebugFormat,

Source

impl<K> ValueDebugFormat for AutoSet<K>

Source

impl<T, const N: usize> ValueDebugFormat for SmallVec<[T; N]>

Source

impl<T> ValueDebugFormat for &T
where T: Debug,

Source

impl<T> ValueDebugFormat for Option<T>

Source

impl<T> ValueDebugFormat for Vec<T>

Implementors

Source

impl ValueDebugFormat for Completion

Available on debug-assertions enabled only.
Source

impl ValueDebugFormat for Effects

Available on debug-assertions enabled only.
Source

impl<A, T> ValueDebugFormat for MappedReadRef<A, T>

Available on debug-assertions enabled only.
Source

impl<K, V> ValueDebugFormat for FxIndexMap<K, V>

Source

impl<T: ValueDebugFormat + Debug + Send + Sync, E: ValueDebugFormat + Debug + Send + Sync> ValueDebugFormat for AdjacencyMap<T, E>

Available on debug-assertions enabled only.
Source

impl<T> ValueDebugFormat for FxIndexSet<T>

Source

impl<T> ValueDebugFormat for OrdResolvedVc<T>
where T: UpcastStrict<Box<dyn ValueDebug>> + Send + Sync + ?Sized,

Available on debug-assertions enabled only.
Source

impl<T> ValueDebugFormat for ReadRef<T>
where T: VcValueType, <<T as VcValueType>::Read as VcRead<T>>::Target: ValueDebugFormat + 'static,

Available on debug-assertions enabled only.
Source

impl<T> ValueDebugFormat for ResolvedVc<T>
where T: UpcastStrict<Box<dyn ValueDebug>> + Send + Sync + ?Sized,

Available on debug-assertions enabled only.
Source

impl<T> ValueDebugFormat for Vc<T>
where T: UpcastStrict<Box<dyn ValueDebug>> + Send + Sync + ?Sized,

Available on debug-assertions enabled only.