RawVcUnpacked

Enum RawVcUnpacked 

pub enum RawVcUnpacked {
    TaskOutput(TaskId),
    TaskCell(TaskId, CellId),
    LocalOutput(ExecutionId, LocalTaskId, TaskPersistence),
}
The unpacked form of RawVc, produced by RawVc::unpack.

Variants



TaskOutput(TaskId)

The synchronous return value of a task (after argument resolution). This is the representation used by OperationVc.



TaskCell(TaskId, CellId)

A pointer to a specific Vc::cell or .cell() call within a task. This is the representation used by ResolvedVc.

CellId contains the ValueTypeId, which can be useful for efficient downcasting.



LocalOutput(ExecutionId, LocalTaskId, TaskPersistence)

The synchronous return value of a local task. This is created when a function is called with unresolved arguments or more explicitly with #[turbo_tasks::function(local)].

Local outputs are only valid within the context of their parent “non-local” task. Turbo Task’s APIs are designed to prevent escapes of local Vcs, but ExecutionId is used for a fallback runtime assertion.