ReadCellTracking

Enum ReadCellTracking 

pub enum ReadCellTracking {
    Tracked {
        key: Option<u64>,
    },
    TrackOnlyError,
    Untracked,
}

Variants



Tracked

Reads are tracked as dependencies of the current task.

Fields

key: Option<u64>

The key used for the dependency



TrackOnlyError

The read is only tracked when there is an error, otherwise it is untracked.

INVALIDATION: Be careful with this, it will not track dependencies, so using it could break cache invalidation.



Untracked

The read is not tracked as a dependency of the current task.

INVALIDATION: Be careful with this, it will not track dependencies, so using it could break cache invalidation.

Implementations

Source

impl ReadCellTracking

pub fn should_track(&self, is_err: bool) -> bool

pub fn key(&self) -> Option<u64>