pub enum ScheduleKey {
Task(TaskId),
LocalTask(ExecutionId, LocalTaskId),
}Expand description
Identifies a scheduled task, so that a read which is about to wait for it can take it out of the
scheduler queue and execute it inline instead (see PriorityRunner::claim and
execute_read_target_inline).
Variants
Task(TaskId)
A cached (non-local) task.
LocalTask(ExecutionId, LocalTaskId)
A local task, which is only known within the execution that created it.