pub enum TaskExecutionReason {
Root,
OutputNotAvailable,
CellNotAvailable,
Invalidated,
ActivateDirty,
ActivateInitial,
Connect,
Stale,
}Variants
Root
A root task was initially scheduled and is executed
OutputNotAvailable
A task output was read, but the output is not available, so the task was scheduled and executed to produce the output
CellNotAvailable
A task cell was read, but the cell content is not available, so the task was scheduled and executed to produce the cell content
Invalidated
A task was marked as dirty and is active on it’s own (maybe root or currently awaited), so it was scheduled and executed to update the task output
ActivateDirty
A dirty task has been activated, so it was scheduled and executed to update the task output
ActivateInitial
A task has been activated for the first time (no output yet), so it was scheduled and executed to produce the task output
Connect
A task was connected as child in active_tracking == false mode for the first time (no
output yet), so it was scheduled and executed to produce the task output.
Or a task was called inside of a turbo_tasks::run closure for the first time (no output
yet), so it was scheduled and executed to produce the task output.
Stale
An in-progress task was marked as stale, so it was scheduled again after execution and is executing again to update the task output.
Implementations