get_serialization_invalidator

Function get_serialization_invalidator 

pub fn get_serialization_invalidator() -> SerializationInvalidator
Returns a SerializationInvalidator that can be used to invalidate the serialization of the current task cells.

Also marks the current task as stateful when the verify_determinism feature is enabled, since State allocation implies interior mutability.