resolve_strongly_consistent_and_take_and_apply_effects

Function resolve_strongly_consistent_and_take_and_apply_effects 

pub async fn resolve_strongly_consistent_and_take_and_apply_effects<T>(
    op: OperationVc<T>,
) -> Result<ResolvedVc<T>>
where T: VcValueType,
AVOID CALLING THIS UNLESS DEEPLY REQUIRED

Like read_strongly_consistent_and_apply_effects, but the Effects directly accessed by calling take_effects on the supplied operation.

Unlike read_strongly_consistent_and_apply_effects, this may be called from inside a turbo-tasks task (it owns the mark/unmark around apply). The consequence is that the effects may be re-applied if that enclosing task is invalidated — acceptable for lazily-created resources.