pub enum VisitControlFlow {
Continue,
Skip,
Exclude,
}Expand description
The control flow of visiting an edge during a graph traversal.
Variants
Continue
The edge is included, and the traversal should continue on the outgoing edges of the given node.
Skip
The edge is included, but the traversal should skip visiting the edges the given node.
Exclude
The edge is excluded, and the traversal should not continue on the outgoing edges of the given node.