pub trait GraphStore: Send {
type Node: Send;
type Edge: Send;
type Handle: Send;
// Required methods
fn insert(
&mut self,
from: Option<(&Self::Handle, Self::Edge)>,
node: Self::Node,
);
fn try_enter(&mut self, node: &Self::Node) -> Option<Self::Handle>;
}Expand description
A graph store is a data structure that will be built up during a graph traversal. It is used to store the results of the traversal.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".