Scope

Struct Scope 

pub struct Scope<'scope, T: Send + 'static, R = ()> { /* private fields */ }
Handle passed to the run closure of scope_unbounded, used to enqueue additional items into the same scope.

Implementations

Source

impl<T: Send + 'static, R: Send> Scope<'_, T, R>

pub fn spawn(&self, item: T)

Enqueue another item to be processed by run. Callable any number of times from inside run, on any drainer thread.

Silently drops item once the scope has aborted.