OrdResolvedVc

Struct OrdResolvedVc 

pub struct OrdResolvedVc<T>
where T: ?Sized,
{ /* private fields */ }
A thin wrapper on ResolvedVc that implements Ord. You must not depend on this to provide deterministic execution (i.e. to produce externally-visible outputs, like when performing chunking) as task ids are non-deterministic across cold executions.

This can be useful to provide a cache key. Given a single instance of turbo-tasks, this will give stable results.

Implementations

Source

impl<T> OrdResolvedVc<T>
where T: ?Sized,

pub fn new(node: ResolvedVc<T>) -> Self

Wraps a ResolvedVc so that it can be ordered. See the type-level documentation for the caveats around determinism.

pub fn deref_vec(vec: Vec<OrdResolvedVc<T>>) -> Vec<ResolvedVc<T>>

Cheaply converts a Vec of ordered ResolvedVcs to a Vec of ResolvedVcs.

pub fn deref_slice(s: &[OrdResolvedVc<T>]) -> &[ResolvedVc<T>]

Cheaply converts a slice of OrdResolvedVcs to a slice of ResolvedVcs.