pub struct SerializationInvalidator { /* private fields */ }Expand description
Allows a turbo-tasks value type to notify the backend that its serialized state has changed out-of-band (i.e. without going through the normal output-cell mechanism).
invalidate must always be called from within a turbo-tasks execution
context (i.e. inside a #[turbo_tasks::function] body or a State
mutation triggered from one), so TURBO_TASKS task-local is always
available and we do not need to capture handles at construction time.
Implementations
Sourceimpl SerializationInvalidator
impl SerializationInvalidator
pub fn invalidate(&self)