pub struct TraitRef<T>where
T: ?Sized,{ /* private fields */ }Expand description
Similar to a ReadRef<T>, but contains a value trait object instead.
Non-turbo-task methods with a &self receiver can be called on this reference.
A TraitRef<T> can be turned back into a value trait vc by calling TraitRef::cell.
Internally it stores a reference counted reference to a value on the heap.
Implementations
Sourceimpl<T> TraitRef<T>where
T: VcValueTrait + ?Sized,
impl<T> TraitRef<T>where
T: VcValueTrait + ?Sized,
Sourcepub fn cell(trait_ref: TraitRef<T>) -> Vc<T>
pub fn cell(trait_ref: TraitRef<T>) -> Vc<T>
Returns a new cell that points to a value that implements the value
trait T.
Sourcepub fn try_downcast<K>(this: TraitRef<T>) -> Option<TraitRef<K>>
pub fn try_downcast<K>(this: TraitRef<T>) -> Option<TraitRef<K>>
Attempts to downcast this trait reference to a sub-trait K, where K
is of the form Box<dyn L> and L: T is a value trait.