pub struct Unused<T> { /* private fields */ }Expand description
A wrapper around a value that is unused.
Implementations
Sourceimpl<T> Unused<T>
impl<T> Unused<T>
Sourcepub unsafe fn new_unchecked(inner: T) -> Self
pub unsafe fn new_unchecked(inner: T) -> Self
Sourcepub unsafe fn get_unchecked(&self) -> &T
pub unsafe fn get_unchecked(&self) -> &T
Get the inner value, without consuming the Unused wrapper.
Safety
The user need to make sure that the value stays unused.