pub enum LocalTaskType {
ResolveNative {
native_fn: &'static NativeFunction,
},
ResolveTrait {
trait_method: &'static TraitMethod,
},
}Variants
ResolveNative
A resolve task, which resolves arguments and calls the function with resolve arguments. The
inner function call will be a PersistentTaskType.
Fields

native_fn: &'static NativeFunctionResolveTrait
A trait method resolve task. It resolves the first (self) argument and looks up the trait
method on that value. Then it calls that method. The method call will do a cache lookup and
might resolve arguments before.
Fields

trait_method: &'static TraitMethodTrait Implementations
Sourceimpl Clone for LocalTaskType
impl Clone for LocalTaskType
Sourcefn clone(&self) -> LocalTaskType
fn clone(&self) -> LocalTaskType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LocalTaskType