Effect

Trait Effect 

pub trait Effect:
    Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required method
    fn capture<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<Box<dyn CapturedEffect>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
An IO Side effect to be computed by turbo tasks and then executed outside of turbo tasks.

Required Methods

fn capture<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Box<dyn CapturedEffect>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Read any Vc data needed for apply() and return the CapturedEffect that performs it.

An implementation may elect to elide capturing data if the EffectStateStorage state is already up to date.