InvalidationReasonKind

Trait InvalidationReasonKind 

pub trait InvalidationReasonKind:
    DynEq
    + DynHash
    + Send
    + Sync
    + 'static {
    // Required method
    fn fmt(
        &self,
        data: &FxIndexSet<StaticOrArc<dyn InvalidationReason>>,
        f: &mut Formatter<'_>,
    ) -> Result;
}
Invalidation reason kind. This is used to merge multiple reasons of the same kind into a combined description.

Reason kinds are used a hash map key, so this need to implement Eq and Hash

Required Methods

fn fmt( &self, data: &FxIndexSet<StaticOrArc<dyn InvalidationReason>>, f: &mut Formatter<'_>, ) -> Result

Displays a description of multiple invalidation reasons of the same kind. It is only called with two or more reasons.