JoinIterExt

Trait JoinIterExt 

pub trait JoinIterExt<T, F>: Iterator
where F: Future<Output = T>,
{ // Required method fn join(self) -> Join<F>; }

Required Methods

fn join(self) -> Join<F>

Returns a future that resolves to a vector of the outputs of the futures in the iterator.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, F, IF, It> JoinIterExt<T, F> for It
where F: Future<Output = T>, IF: IntoFuture<Output = T, IntoFuture = F>, It: Iterator<Item = IF>,