pub unsafe trait OperationValue { }Expand description
Indicates that a type does not contain any instances of Vc or ResolvedVc. It may contain
OperationVc.
Safety
This trait is marked as unsafe. You should not derive it yourself, but instead you should rely
on #[derive(OperationValue)] to do it for you.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl OperationValue for ()
impl OperationValue for AtomicBool
impl OperationValue for AtomicI8
impl OperationValue for AtomicI16
impl OperationValue for AtomicI32
impl OperationValue for AtomicI64
impl OperationValue for AtomicU8
impl OperationValue for AtomicU16
impl OperationValue for AtomicU32
impl OperationValue for AtomicU64
impl OperationValue for AtomicUsize
impl OperationValue for Duration
impl OperationValue for Map<String, Value>
impl OperationValue for Path
impl OperationValue for PathBuf
impl OperationValue for RcStr
impl OperationValue for String
impl OperationValue for Value
impl OperationValue for bool
impl OperationValue for char
impl OperationValue for f32
impl OperationValue for f64
impl OperationValue for i8
impl OperationValue for i16
impl OperationValue for i32
impl OperationValue for i64
impl OperationValue for i128
impl OperationValue for isize
impl OperationValue for str
impl OperationValue for u8
impl OperationValue for u16
impl OperationValue for u32
impl OperationValue for u64
impl OperationValue for u128
impl OperationValue for usize
impl<A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(A, Z, Y, X, W, V, U, T) -> Return
impl<A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (A, Z, Y, X, W, V, U, T)
impl<B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(B, A, Z, Y, X, W, V, U, T) -> Return
impl<B: OperationValue + ToOwned + ?Sized> OperationValue for Cow<'_, B>
impl<B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (B, A, Z, Y, X, W, V, U, T)
impl<C, B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(C, B, A, Z, Y, X, W, V, U, T) -> Return
impl<C: OperationValue, B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (C, B, A, Z, Y, X, W, V, U, T)
impl<D, C, B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(D, C, B, A, Z, Y, X, W, V, U, T) -> Return
impl<D: OperationValue, C: OperationValue, B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (D, C, B, A, Z, Y, X, W, V, U, T)
impl<E, D, C, B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(E, D, C, B, A, Z, Y, X, W, V, U, T) -> Return
impl<E: OperationValue, D: OperationValue, C: OperationValue, B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (E, D, C, B, A, Z, Y, X, W, V, U, T)
impl<K: OperationValue, V: OperationValue, S, const I: usize> OperationValue for AutoMap<K, V, S, I>
impl<K: OperationValue, V: OperationValue, S> OperationValue for HashMap<K, V, S>
impl<K: OperationValue, V: OperationValue, S> OperationValue for IndexMap<K, V, S>
impl<K: OperationValue, V: OperationValue> OperationValue for BTreeMap<K, V>
impl<K: OperationValue, V: OperationValue> OperationValue for FrozenMap<K, V>
impl<L: OperationValue, R: OperationValue> OperationValue for Either<L, R>
impl<T, Return> OperationValue for fn(T) -> Return
impl<T: ?Sized> OperationValue for PhantomData<T>
impl<T: OperationValue + ?Sized> OperationValue for &T
impl<T: OperationValue + ?Sized> OperationValue for &mut T
impl<T: OperationValue + ?Sized> OperationValue for Arc<T>
impl<T: OperationValue + ?Sized> OperationValue for Box<T>
impl<T: OperationValue + ?Sized> OperationValue for Mutex<T>
impl<T: OperationValue + ?Sized> OperationValue for Mutex<T>
impl<T: OperationValue + ?Sized> OperationValue for RefCell<T>
impl<T: OperationValue, E: OperationValue> OperationValue for Result<T, E>
impl<T: OperationValue, S, const I: usize> OperationValue for AutoSet<T, S, I>
impl<T: OperationValue, S> OperationValue for HashSet<T, S>
impl<T: OperationValue, S> OperationValue for IndexSet<T, S>
impl<T: OperationValue, const N: usize> OperationValue for SmallVec<[T; N]>
impl<T: OperationValue, const N: usize> OperationValue for [T; N]
impl<T: OperationValue> OperationValue for (T,)
impl<T: OperationValue> OperationValue for BTreeSet<T>
impl<T: OperationValue> OperationValue for FrozenSet<T>
impl<T: OperationValue> OperationValue for Option<T>
impl<T: OperationValue> OperationValue for Vec<T>
impl<T: OperationValue> OperationValue for [T]
impl<T> OperationValue for Pin<T>
impl<U, T, Return> OperationValue for fn(U, T) -> Return
impl<U: OperationValue, T: OperationValue> OperationValue for (U, T)
impl<V, U, T, Return> OperationValue for fn(V, U, T) -> Return
impl<V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (V, U, T)
impl<W, V, U, T, Return> OperationValue for fn(W, V, U, T) -> Return
impl<W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (W, V, U, T)
impl<X, W, V, U, T, Return> OperationValue for fn(X, W, V, U, T) -> Return
impl<X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (X, W, V, U, T)
impl<Y, X, W, V, U, T, Return> OperationValue for fn(Y, X, W, V, U, T) -> Return
impl<Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (Y, X, W, V, U, T)
impl<Z, Y, X, W, V, U, T, Return> OperationValue for fn(Z, Y, X, W, V, U, T) -> Return
impl<Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (Z, Y, X, W, V, U, T)
Implementors
impl OperationValue for Error
impl OperationValue for Event
impl OperationValue for Invalidator
impl<T: ?Sized + Send> OperationValue for GcRoot<T>
Safety: a GcRoot contains exactly one OperationVc and no Vc or ResolvedVc, which
is what OperationValue asserts.