TryFlatJoinIterExt

Trait TryFlatJoinIterExt 

pub trait TryFlatJoinIterExt<F, I, U>: Iterator
where F: Future<Output = Result<I>>, I: IntoIterator<IntoIter = U, Item = U::Item>, U: Iterator,
{ // Required method fn try_flat_join(self) -> TryFlatJoin<F>; }

Required Methods

fn try_flat_join(self) -> TryFlatJoin<F>

Returns a future that resolves to a vector of the outputs of the futures in the iterator, or to an error if one of the futures fail.

It also flattens the result.

Unlike Futures::future::try_join_all, this returns the Error that occurs first in the list of futures, not the first to fail in time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, IF, It, I, U> TryFlatJoinIterExt<F, I, U> for It
where F: Future<Output = Result<I>>, IF: IntoFuture<Output = Result<I>, IntoFuture = F>, It: Iterator<Item = IF>, I: IntoIterator<IntoIter = U, Item = U::Item>, U: Iterator,