UpcastStrict

Trait UpcastStrict 

pub unsafe trait UpcastStrict<T>: Upcast<T>
where T: VcValueTrait + ?Sized,
{ }
A specialization of Upcast that ensures that the upcast is strict meaning that T !== Self.

See VcValueTrait for example usage.

Safety

The implementor of this trait must ensure that Self implements the trait T and that Self is not equal to T.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl UpcastStrict<Box<dyn ValueDebug>> for ()

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Box<dyn Effect>

Available on debug-assertions enabled only.
Source

impl UpcastStrict<Box<dyn ValueDebug>> for Box<dyn ValueDefault>

Available on debug-assertions enabled only.
Source

impl UpcastStrict<Box<dyn ValueDebug>> for Box<dyn ValueToString>

Available on debug-assertions enabled only.
Source

impl UpcastStrict<Box<dyn ValueDebug>> for Duration

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Option<RcStr>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Option<String>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Option<bool>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Option<u16>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Option<u64>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for RcStr

Source

impl UpcastStrict<Box<dyn ValueDebug>> for String

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Value

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Vec<RcStr>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Vec<bool>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for Vec<u8>

Source

impl UpcastStrict<Box<dyn ValueDebug>> for bool

Source

impl UpcastStrict<Box<dyn ValueDebug>> for i8

Source

impl UpcastStrict<Box<dyn ValueDebug>> for i16

Source

impl UpcastStrict<Box<dyn ValueDebug>> for i32

Source

impl UpcastStrict<Box<dyn ValueDebug>> for i64

Source

impl UpcastStrict<Box<dyn ValueDebug>> for i128

Source

impl UpcastStrict<Box<dyn ValueDebug>> for isize

Source

impl UpcastStrict<Box<dyn ValueDebug>> for u8

Source

impl UpcastStrict<Box<dyn ValueDebug>> for u16

Source

impl UpcastStrict<Box<dyn ValueDebug>> for u32

Source

impl UpcastStrict<Box<dyn ValueDebug>> for u64

Source

impl UpcastStrict<Box<dyn ValueDebug>> for u128

Source

impl UpcastStrict<Box<dyn ValueDebug>> for usize

Source

impl UpcastStrict<Box<dyn ValueDefault>> for ()

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Duration

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Option<RcStr>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Option<String>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Option<bool>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Option<u16>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Option<u64>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for RcStr

Source

impl UpcastStrict<Box<dyn ValueDefault>> for String

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Value

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Vec<RcStr>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Vec<bool>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for Vec<u8>

Source

impl UpcastStrict<Box<dyn ValueDefault>> for bool

Source

impl UpcastStrict<Box<dyn ValueDefault>> for i8

Source

impl UpcastStrict<Box<dyn ValueDefault>> for i16

Source

impl UpcastStrict<Box<dyn ValueDefault>> for i32

Source

impl UpcastStrict<Box<dyn ValueDefault>> for i64

Source

impl UpcastStrict<Box<dyn ValueDefault>> for i128

Source

impl UpcastStrict<Box<dyn ValueDefault>> for isize

Source

impl UpcastStrict<Box<dyn ValueDefault>> for u8

Source

impl UpcastStrict<Box<dyn ValueDefault>> for u16

Source

impl UpcastStrict<Box<dyn ValueDefault>> for u32

Source

impl UpcastStrict<Box<dyn ValueDefault>> for u64

Source

impl UpcastStrict<Box<dyn ValueDefault>> for u128

Source

impl UpcastStrict<Box<dyn ValueDefault>> for usize

Source

impl UpcastStrict<Box<dyn ValueToString>> for RcStr

Implementors