pub trait ValueDebugFormat {
// Required method
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>;
}Expand description
Use autoref specialization to implement ValueDebug for T: Debug.
Required Methods
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Implementations on Foreign Types
Sourceimpl ValueDebugFormat for RcStr
impl ValueDebugFormat for RcStr
fn value_debug_format(&self, _depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl ValueDebugFormat for String
impl ValueDebugFormat for String
fn value_debug_format(&self, _depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat> ValueDebugFormat for (A,)
impl<A: ValueDebugFormat> ValueDebugFormat for (A,)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat> ValueDebugFormat for (A, B)
impl<A: ValueDebugFormat, B: ValueDebugFormat> ValueDebugFormat for (A, B)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat> ValueDebugFormat for (A, B, C)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat> ValueDebugFormat for (A, B, C)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat> ValueDebugFormat for (A, B, C, D)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat> ValueDebugFormat for (A, B, C, D)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat, K: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J, K)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat, K: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J, K)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat, K: ValueDebugFormat, L: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J, K, L)
impl<A: ValueDebugFormat, B: ValueDebugFormat, C: ValueDebugFormat, D: ValueDebugFormat, E: ValueDebugFormat, F: ValueDebugFormat, G: ValueDebugFormat, H: ValueDebugFormat, I: ValueDebugFormat, J: ValueDebugFormat, K: ValueDebugFormat, L: ValueDebugFormat> ValueDebugFormat for (A, B, C, D, E, F, G, H, I, J, K, L)
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<K> ValueDebugFormat for AutoSet<K>where
K: ValueDebugFormat,
impl<K> ValueDebugFormat for AutoSet<K>where
K: ValueDebugFormat,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<K, V> ValueDebugFormat for AutoMap<K, V>where
K: Debug,
V: ValueDebugFormat,
impl<K, V> ValueDebugFormat for AutoMap<K, V>where
K: Debug,
V: ValueDebugFormat,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<K, V, S> ValueDebugFormat for HashMap<K, V, S>where
K: Debug,
V: ValueDebugFormat,
impl<K, V, S> ValueDebugFormat for HashMap<K, V, S>where
K: Debug,
V: ValueDebugFormat,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<T> ValueDebugFormat for Option<T>where
T: ValueDebugFormat,
impl<T> ValueDebugFormat for Option<T>where
T: ValueDebugFormat,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<T> ValueDebugFormat for &Twhere
T: Debug,
impl<T> ValueDebugFormat for &Twhere
T: Debug,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<T> ValueDebugFormat for Vec<T>where
T: ValueDebugFormat,
impl<T> ValueDebugFormat for Vec<T>where
T: ValueDebugFormat,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Sourceimpl<T, const N: usize> ValueDebugFormat for SmallVec<[T; N]>where
T: ValueDebugFormat,
impl<T, const N: usize> ValueDebugFormat for SmallVec<[T; N]>where
T: ValueDebugFormat,
fn value_debug_format(&self, depth: usize) -> ValueDebugFormatString<'_>
Implementors
impl ValueDebugFormat for Completion
Available on debug-assertions enabled only.
impl ValueDebugFormat for Effects
Available on debug-assertions enabled only.
impl<A, T> ValueDebugFormat for MappedReadRef<A, T>where
T: ValueDebugFormat,
Available on debug-assertions enabled only.
impl<K, V> ValueDebugFormat for FxIndexMap<K, V>where
K: ValueDebugFormat,
V: ValueDebugFormat,
impl<T> ValueDebugFormat for ReadRef<T>
Available on debug-assertions enabled only.
impl<T> ValueDebugFormat for ResolvedVc<T>
Available on debug-assertions enabled only.
impl<T> ValueDebugFormat for Vc<T>
Available on debug-assertions enabled only.
impl<T> ValueDebugFormat for FxIndexSet<T>where
T: ValueDebugFormat,
impl<T: ValueDebugFormat + Debug + Send + Sync, E: ValueDebugFormat + Debug + Send + Sync> ValueDebugFormat for AdjacencyMap<T, E>
Available on debug-assertions enabled only.