pub fn mark_stateful()Expand description
Marks the current task as stateful. This is used to indicate that the task has interior mutability (e.g., via State or TransientState), which means the task may produce different outputs even with the same inputs.
Only has an effect when the verify_determinism feature is enabled.