pub fn mark_top_level_task()Expand description
Marks the current task context as being in a top-level task. When in a top-level task, eventually consistent reads will panic. It is almost always a mistake to perform an eventually consistent read at the top-level of the application.