pub struct Effects { /* private fields */ }Expand description
Captured effects from an operation. This struct can be used to return Effects from a turbo-tasks function and apply them later.
Implementations
Sourceimpl Effects
impl Effects
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
ResolvedVc.
Cell is selected based on the value type and call order of cell.
Sourceimpl Effects
impl Effects
Sourcepub async fn apply(&self) -> Result<(), Arc<dyn EffectError>>
pub async fn apply(&self) -> Result<(), Arc<dyn EffectError>>
Applies all effects that have been captured.
On first call: groups effects by key, detects duplicates/conflicts, caches deduped indices. On subsequent calls: skips grouping (reuses cached indices), only runs per-key state checks.
apply must only be used in a “top-level” task (e.g. run_once), after
take_effects is called from an operation read with strong
consistency.
See take_effects for example usage.