ValueType

Struct ValueType 

pub struct ValueType {
    pub ty: RegistryType,
    pub bincode: Option<(AnyEncodeFn, AnyDecodeFn<SharedReference>)>,
    /* private fields */
}
A definition of a type of data.

Contains a list of traits and trait methods that are available on that type.

Fields

ty: RegistryTypebincode: Option<(AnyEncodeFn, AnyDecodeFn<SharedReference>)>

Functions to convert to write the type to a buffer or read it from a buffer.

Implementations

Source

impl ValueType

pub const fn new<T: VcValueType>(global_name: &'static str) -> Self

This is internally used by #[turbo_tasks::value].

pub const fn new_with_bincode<T: VcValueType + Encode + Decode<()>>( global_name: &'static str, ) -> Self

This is internally used by #[turbo_tasks::value].

pub const fn new_with_bincode_wrappers<T: VcValueType, E: ManualEncodeWrapper<Value = T>, D: ManualDecodeWrapper<Value = T>>( global_name: &'static str, ) -> Self

This is used internally by turbo_tasks_macros::primitive to encode/decode foreign types that cannot implement the bincode traits due to the orphan rules.

This is done by constructing wrapper types that implement the bincode traits on behalf of the wrapped type.

pub fn type_id(&self) -> TypeId

Returns the TypeId of the concrete type this ValueType represents.

pub fn get_trait_method( &self, trait_method: &'static TraitMethod, ) -> Option<&'static NativeFunction>

pub fn has_trait(&self, trait_type: &TraitTypeId) -> bool