OperationValue

Trait OperationValue 

pub unsafe trait OperationValue { }
Indicates that a type does not contain any instances of Vc or ResolvedVc. It may contain OperationVc.

Safety

This trait is marked as unsafe. You should not derive it yourself, but instead you should rely on #[derive(OperationValue)] to do it for you.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl OperationValue for ()

Source

impl OperationValue for AtomicBool

Source

impl OperationValue for AtomicI8

Source

impl OperationValue for AtomicI16

Source

impl OperationValue for AtomicI32

Source

impl OperationValue for AtomicI64

Source

impl OperationValue for AtomicU8

Source

impl OperationValue for AtomicU16

Source

impl OperationValue for AtomicU32

Source

impl OperationValue for AtomicU64

Source

impl OperationValue for AtomicUsize

Source

impl OperationValue for Duration

Source

impl OperationValue for Map<String, Value>

Source

impl OperationValue for Path

Source

impl OperationValue for PathBuf

Source

impl OperationValue for RcStr

Source

impl OperationValue for String

Source

impl OperationValue for Value

Source

impl OperationValue for bool

Source

impl OperationValue for char

Source

impl OperationValue for f32

Source

impl OperationValue for f64

Source

impl OperationValue for i8

Source

impl OperationValue for i16

Source

impl OperationValue for i32

Source

impl OperationValue for i64

Source

impl OperationValue for i128

Source

impl OperationValue for isize

Source

impl OperationValue for str

Source

impl OperationValue for u8

Source

impl OperationValue for u16

Source

impl OperationValue for u32

Source

impl OperationValue for u64

Source

impl OperationValue for u128

Source

impl OperationValue for usize

Source

impl<A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(A, Z, Y, X, W, V, U, T) -> Return

Source

impl<A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (A, Z, Y, X, W, V, U, T)

Source

impl<B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(B, A, Z, Y, X, W, V, U, T) -> Return

Source

impl<B: OperationValue + ToOwned + ?Sized> OperationValue for Cow<'_, B>

Source

impl<B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (B, A, Z, Y, X, W, V, U, T)

Source

impl<C, B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(C, B, A, Z, Y, X, W, V, U, T) -> Return

Source

impl<C: OperationValue, B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (C, B, A, Z, Y, X, W, V, U, T)

Source

impl<D, C, B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(D, C, B, A, Z, Y, X, W, V, U, T) -> Return

Source

impl<D: OperationValue, C: OperationValue, B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (D, C, B, A, Z, Y, X, W, V, U, T)

Source

impl<E, D, C, B, A, Z, Y, X, W, V, U, T, Return> OperationValue for fn(E, D, C, B, A, Z, Y, X, W, V, U, T) -> Return

Source

impl<E: OperationValue, D: OperationValue, C: OperationValue, B: OperationValue, A: OperationValue, Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (E, D, C, B, A, Z, Y, X, W, V, U, T)

Source

impl<K: OperationValue, V: OperationValue, S, const I: usize> OperationValue for AutoMap<K, V, S, I>

Source

impl<K: OperationValue, V: OperationValue, S> OperationValue for HashMap<K, V, S>

Source

impl<K: OperationValue, V: OperationValue, S> OperationValue for IndexMap<K, V, S>

Source

impl<K: OperationValue, V: OperationValue> OperationValue for BTreeMap<K, V>

Source

impl<K: OperationValue, V: OperationValue> OperationValue for FrozenMap<K, V>

Source

impl<L: OperationValue, R: OperationValue> OperationValue for Either<L, R>

Source

impl<T, Return> OperationValue for fn(T) -> Return

Source

impl<T: ?Sized> OperationValue for PhantomData<T>

Source

impl<T: OperationValue + ?Sized> OperationValue for &T

Source

impl<T: OperationValue + ?Sized> OperationValue for &mut T

Source

impl<T: OperationValue + ?Sized> OperationValue for Arc<T>

Source

impl<T: OperationValue + ?Sized> OperationValue for Box<T>

Source

impl<T: OperationValue + ?Sized> OperationValue for Mutex<T>

Source

impl<T: OperationValue + ?Sized> OperationValue for Mutex<T>

Source

impl<T: OperationValue + ?Sized> OperationValue for RefCell<T>

Source

impl<T: OperationValue, E: OperationValue> OperationValue for Result<T, E>

Source

impl<T: OperationValue, S, const I: usize> OperationValue for AutoSet<T, S, I>

Source

impl<T: OperationValue, S> OperationValue for HashSet<T, S>

Source

impl<T: OperationValue, S> OperationValue for IndexSet<T, S>

Source

impl<T: OperationValue, const N: usize> OperationValue for SmallVec<[T; N]>

Source

impl<T: OperationValue, const N: usize> OperationValue for [T; N]

Source

impl<T: OperationValue> OperationValue for (T,)

Source

impl<T: OperationValue> OperationValue for BTreeSet<T>

Source

impl<T: OperationValue> OperationValue for FrozenSet<T>

Source

impl<T: OperationValue> OperationValue for Option<T>

Source

impl<T: OperationValue> OperationValue for Vec<T>

Source

impl<T: OperationValue> OperationValue for [T]

Source

impl<T> OperationValue for Pin<T>
where T: Deref, <T as Deref>::Target: OperationValue,

Source

impl<U, T, Return> OperationValue for fn(U, T) -> Return

Source

impl<U: OperationValue, T: OperationValue> OperationValue for (U, T)

Source

impl<V, U, T, Return> OperationValue for fn(V, U, T) -> Return

Source

impl<V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (V, U, T)

Source

impl<W, V, U, T, Return> OperationValue for fn(W, V, U, T) -> Return

Source

impl<W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (W, V, U, T)

Source

impl<X, W, V, U, T, Return> OperationValue for fn(X, W, V, U, T) -> Return

Source

impl<X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (X, W, V, U, T)

Source

impl<Y, X, W, V, U, T, Return> OperationValue for fn(Y, X, W, V, U, T) -> Return

Source

impl<Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (Y, X, W, V, U, T)

Source

impl<Z, Y, X, W, V, U, T, Return> OperationValue for fn(Z, Y, X, W, V, U, T) -> Return

Source

impl<Z: OperationValue, Y: OperationValue, X: OperationValue, W: OperationValue, V: OperationValue, U: OperationValue, T: OperationValue> OperationValue for (Z, Y, X, W, V, U, T)

Implementors