pub trait TryFlatJoinIterExt<F, I, U>: Iterator{
// Required method
fn try_flat_join(self) -> TryFlatJoin<F>;
}Required Methods
Sourcefn try_flat_join(self) -> TryFlatJoin<F>
fn try_flat_join(self) -> TryFlatJoin<F>
Returns a future that resolves to a vector of the outputs of the futures in the iterator, or to an error if one of the futures fail.
It also flattens the result.
Unlike Futures::future::try_join_all, this returns the Error that
occurs first in the list of futures, not the first to fail in time.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".