pub unsafe trait UpcastStrict<T>: Upcast<T>where
T: VcValueTrait + ?Sized,{ }Expand description
A specialization of Upcast that ensures that the upcast is strict meaning that T !== Self.
See VcValueTrait for example usage.
Safety
The implementor of this trait must ensure that Self implements the
trait T and that Self is not equal to T.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl UpcastStrict<Box<dyn ValueDebug>> for ()
impl UpcastStrict<Box<dyn ValueDebug>> for Box<dyn Effect>
Available on debug-assertions enabled only.
impl UpcastStrict<Box<dyn ValueDebug>> for Box<dyn ValueDefault>
Available on debug-assertions enabled only.
impl UpcastStrict<Box<dyn ValueDebug>> for Box<dyn ValueToString>
Available on debug-assertions enabled only.